@@ -28,7 +28,7 @@ api.add_resource(resources.AlbumResource, '/albums', '/album/<int:album_id>',
                  '/album/<album_slug>', endpoint='album')
 
 # Tracks
-api.add_resource(resources.TracksResource, '/tracks', '/track/<int:track_id>',
+api.add_resource(resources.TrackResource, '/tracks', '/track/<int:track_id>',
                  '/track/<track_slug>', endpoint='track')
 api.add_resource(resources.LyricsResource, '/track/<int:track_id>/lyrics',
                  '/track/<track_slug>/lyrics', endpoint='lyrics')
@@ -52,7 +52,8 @@ def before_request():
 def after_request(response):
     if getattr(g, 'cors', False):
         response.headers['Access-Control-Allow-Origin'] = g.cors
-        response.headers['Access-Control-Allow-Headers'] = 'Content-Type'
+        response.headers['Access-Control-Allow-Headers'] = \
+            'Accept, Content-Type, Origin, X-Requested-With'
 
     return response
 
