@@ -15,7 +15,7 @@ from shiva.fields import (Boolean, ForeignKeyField, InstanceURI,
 from shiva.http import Resource, JSONResponse
 from shiva.lyrics import get_lyrics
 from shiva.mocks import ShowModel
-from shiva.models import Artist, Album, Track, Lyrics
+from shiva.models import Artist, Album, Track, LyricsCache
 from shiva.utils import get_logger
 
 log = get_logger()
@@ -51,9 +51,6 @@ def paginate(queryset):
 
     total = queryset.count()
 
-    if total < page_size:
-        return queryset
-
     limit = page_size
     offset = page_size * (page_number - 1)
 
@@ -197,7 +194,7 @@ class AlbumResource(Resource):
         _album = marshal(album, self.get_resource_fields())
         _album['tracks'] = []
 
-        tracks = TracksResource()
+        tracks = TrackResource()
 
         for track in album.tracks.order_by('number', 'title'):
             _album['tracks'].append(tracks.get_full_tree(track))
@@ -218,7 +215,7 @@ class AlbumResource(Resource):
         return {}
 
 
-class TracksResource(Resource):
+class TrackResource(Resource):
     """
     """
 
@@ -373,7 +370,7 @@ class LyricsResource(Resource):
             return JSONResponse(400)
 
         track = Track.query.get(track_id)
-        lyric = Lyrics(track=track, text=text)
+        lyric = LyricsCache(track=track, text=text)
 
         g.db.session.add(lyric)
         g.db.commit()
